@@ -504,6 +504,12 @@ gethash (char const *revno, struct hash *ht)
 }
 
 
+struct fwref
+{
+  char const *revno;
+  size_t lno;                           /* zeroed on match */
+};
+
 struct repo *
 empty_repo (struct divvy *to)
 {
@@ -529,6 +535,7 @@ full (struct divvy *to, struct fro *f)
   size_t count;
   struct link box, *tp;
   struct wlink *follow;
+  struct wlink *all_br = NULL;
   struct grok *g = FZLLOC (struct grok);
   struct repo *repo = empty_repo (to);
 
@@ -648,6 +655,8 @@ full (struct divvy *to, struct fro *f)
   CBEG ("revisions");
   {
     struct wlink wbox, *wtp;
+    struct notyet *prev = NULL;
+    struct fwref *fw;
 
     for (count = 0, wbox.next = repo->deltas, wtp = &wbox;
          MAYBE_REVNO (g);
@@ -655,14 +664,33 @@ full (struct divvy *to, struct fro *f)
       {
         struct notyet *ny = STRUCTALLOC (to, struct notyet);
         struct delta *d = ny->d = STRUCTALLOC (to, struct delta);
+        size_t numlen = XREP (g).size;
 
         STASH (d->num);
+        /* Check that a new branch is properly forward-referenced.  */
+        if (prev && !prev->next
+            && 2 <= countnumflds (d->num))
+          {
+            struct wlink *ls;
+
+            for (ls = all_br; ls; ls = ls->next)
+              if ((fw = ls->entry)->lno
+                  && STR_SAME (d->num, fw->revno))
+                {
+                  fw->lno = 0;
+                  break;
+                }
+            if (!ls)
+              BUMMER ("unexpected new branch %s: %s", ks_revno, d->num);
+          }
+
         d->branches = NULL;             /* see ‘grok_all’ */
         d->ilk = NULL;                  /* see ‘grok_all’ */
         d->lockedby = NULL;             /* see ‘grok_resynch’ */
         d->pretty_log.string = NULL;
         d->pretty_log.size = 0;
         d->selector = true;
+        d->log = NULL;
 
         STASH (ny->revno);
         CBEG (ny->revno);
@@ -685,7 +713,20 @@ full (struct divvy *to, struct fro *f)
         SYNCH (g, branches);
         box.next = NULL, tp = &box;
         while (MAYBE_REVNO (g))
-          HANG (XREP (g).string);
+          {
+            /* Branches must begin with the branch point revision.  */
+            if (numlen >= XREP (g).size
+                || strncmp (d->num, XREP (g).string, numlen)
+                || '.' != XREP (g).string[numlen]
+                || 2 != countnumflds (XREP (g).string + numlen + 1))
+              BUMMER ("invalid branch `%s' at branchpoint `%s'",
+                      XREP (g).string, d->num);
+            fw = STRUCTALLOC (g->tranquil, struct fwref);
+            fw->revno = XREP (g).string;
+            fw->lno = g->lno;
+            all_br = wprepend (fw, all_br, g->tranquil);
+            HANG (XREP (g).string);
+          }
         ny->branches = box.next;
         SEMI (g, branches);
 
@@ -709,7 +750,16 @@ full (struct divvy *to, struct fro *f)
         CEND ();
         wtp = wextend (wtp, ny, to);
         puthash (to, ny, repo->ht);
+        prev = ny;
       }
+    /* Check that all forward references were matched.  */
+    for (; all_br; all_br = all_br->next)
+      if ((fw = all_br->entry)->lno)
+        {
+          /* Jam line number for error message. */
+          g->lno = fw->lno;
+          BUMMER ("branch refers to %s `%s'", ks_ner, fw->revno);
+        }
     repo->deltas = wbox.next;
     repo->deltas_count = count;
   }
@@ -765,6 +815,8 @@ full (struct divvy *to, struct fro *f)
       follow->entry = ny;
       follow = follow->next;
       d = ny->d;
+      if (d->log)
+        BUMMER ("duplicate delta log for %s `%s'", ks_revno, d->num);
       d->neck = neck;
       SYNCH (g, log);
       MUST_ATAT (g, &d->log, log);
