@@ -29,60 +29,49 @@
 #include <signal.h>
 #include <unistd.h>
 #include <string.h>
-#include "sig2str.h"
+#ifdef HAVE_UCONTEXT_H
+#include <ucontext.h>
+#endif
+#ifdef HAVE_SIGINFO_H
+#include <siginfo.h>
+#endif
 #include "b-complain.h"
 #include "b-divvy.h"
 #include "b-excwho.h"
 #include "b-isr.h"
 
+void
+maybe_reset_sigchld (void)
+{
+#if BAD_WAIT_IF_SIGCHLD_IGNORED
+#ifndef SIGCHLD
+#define SIGCHLD SIGCLD
+#endif
+  signal (SIGCHLD, SIG_DFL);
+#endif  /* BAD_WAIT_IF_SIGCHLD_IGNORED */
+}
+
 /* Avoid calling ‘sprintf’ etc., in case they're not reentrant.  */
 
 static void
 werr (char const *s)
 {
-  write (STDERR_FILENO, s, strlen (s));
+  ssize_t len;
+
+  if (! (len = strlen (s)))
+    return;
+
+  if (len != write (STDERR_FILENO, s, len))
+    PROGRAM (exiterr) ();
 }
 
 void
 complain_signal (char const *msg, int signo)
 {
-#ifndef HAVE_PSIGNAL
   werr (msg);
   werr (": ");
-#ifndef HAVE_STRSIGNAL
-  {
-    char buf[SIG2STR_MAX + 1];
-
-    if (PROB (sig2str (signo, buf)))
-      {
-        char *w = buf + SIG2STR_MAX;
-
-        werr ("Unknown signal ");
-        *w-- = '\0';
-        if (!signo)
-          *w-- = '0';
-        else
-          while (signo)
-            {
-              *w-- = (signo % 10) + '0';
-              signo /= 10;
-            }
-        werr (1 + w);
-      }
-    else
-      {
-        werr ("SIG");
-        werr (buf);
-      }
-  }
-#else  /* HAVE_STRSIGNAL */
   werr (strsignal (signo));
-#endif  /* HAVE_STRSIGNAL */
   werr ("\n");
-
-#else  /* HAVE_PSIGNAL */
-  psignal (signo, msg);
-#endif  /* HAVE_PSIGNAL */
 }
 
 struct isr_scratch
@@ -103,12 +92,12 @@ struct isr_scratch
 
 void
 access_page (struct isr_scratch *scratch,
-             char const *filename, void const *p)
+             char const *filename, char const *p)
 {
-  unsigned char volatile t;
+  char volatile t;
 
   ISR (access_name) = filename;
-  t = *((unsigned char *) p);
+  t = *p;
   ISR (access_name) = NULL;
 }
 
@@ -125,22 +114,9 @@ ignore (struct isr_scratch *scratch)
 static struct isr_scratch *
 scratch_from_context (void *c)
 {
-#ifndef HAVE_SIGACTION
-
-  /* FIXME: The reference to ISR_SCRATCH prevents this module (b-isr.c)
-     from being completely reentrant, which would be a nice, but not
-     necessary, for the future libgnurcs.  The useless ‘c ? c :’
-     prevents a compiler warning about unused parameter ‘c’.  */
-
-  return c ? c : ISR_SCRATCH;
-
-#else
-
   ucontext_t *uc = c;
 
   return (struct isr_scratch *)(uc->uc_stack.ss_sp) - 1;
-
-#endif
 }
 
 static void
@@ -149,10 +125,6 @@ catchsigaction (int signo, siginfo_t *info, void *c)
   struct isr_scratch *scratch = scratch_from_context (c);
   bool from_mmap = MMAP_SIGNAL && MMAP_SIGNAL == signo;
 
-  if (SIG_ZAPS_HANDLER)
-    /* If a signal arrives before we reset the handler, we lose.  */
-    signal (signo, SIG_IGN);
-
   if (ISR (level))
     {
       ISR (held) = signo;
@@ -201,19 +173,9 @@ catchsigaction (int signo, siginfo_t *info, void *c)
   PROGRAM (exiterr) ();
 }
 
-#if !defined HAVE_SIGACTION
 static void
-catchsig (int signo)
+setup_catchsig (size_t count, int const set[count])
 {
-  catchsigaction (signo, NULL, NULL);
-}
-#endif  /* !defined HAVE_SIGACTION */
-
-static void
-setup_catchsig (size_t count, const int const set[count])
-{
-#if defined HAVE_SIGACTION
-
   sigset_t blocked;
 
 #define MUST(x)  if (PROB (x)) goto fail
@@ -242,47 +204,9 @@ setup_catchsig (size_t count, const int const set[count])
     }
 
 #undef MUST
-
-#else  /* !defined HAVE_SIGACTION */
-#if defined HAVE_SIGBLOCK
-
-  int mask = 0;
-
-  for (size_t i = 0; i < count; i++)
-    mask |= 1 << (set[i] - 1);
-  mask = sigblock (mask);
-
-  for (size_t i = 0; i < count; i++)
-    {
-      int sig = set[i];
-
-      if (SIG_IGN == signal (sig, catchsig)
-          && catchsig != signal (sig, SIG_IGN))
-        PFATAL ("signal catcher failure");
-    }
-
-  sigsetmask (mask);
-
-#else  /* !defined HAVE_SIGBLOCK */
-
-  for (size_t i = 0; i < count; i++)
-    {
-      int sig = set[i];
-
-      if (SIG_IGN != signal (sig, SIG_IGN)
-          && SIG_IGN != signal (sig, catchsig))
-        PFATAL ("signal catcher failure");
-    }
-
-#endif  /* !defined HAVE_SIGBLOCK */
-#endif  /* !defined HAVE_SIGACTION */
 }
 
-#if defined HAVE_SIGACTION
 #define ISR_STACK_SIZE  (10 * SIGSTKSZ)
-#else
-#define ISR_STACK_SIZE  0
-#endif
 
 #define SCRATCH_SIZE  sizeof (struct isr_scratch)
 
@@ -291,7 +215,7 @@ isr_init (bool *be_quiet)
 {
   /* Allocate a contiguous range for the scratch space,
      plus (possibly) space for the alternate sig stack.  */
-  struct isr_scratch *scratch = alloc (SHARED, "isr scratch",
+  struct isr_scratch *scratch = alloc (PLEXUS, "isr scratch",
                                        SCRATCH_SIZE + ISR_STACK_SIZE);
 
 #if ISR_STACK_SIZE
@@ -325,7 +249,7 @@ isr_do (struct isr_scratch *scratch, enum isr_actions action)
     {
     case ISR_CATCHINTS:
       {
-        const int const regular[] =
+        int const regular[] =
           {
             SIGHUP,
             SIGINT,
@@ -365,7 +289,7 @@ isr_do (struct isr_scratch *scratch, enum isr_actions action)
          This can also occur if someone truncates the file,
          even without NFS.  */
       {
-        const int const mmapsigs[] = { MMAP_SIGNAL };
+        int const mmapsigs[] = { MMAP_SIGNAL };
 
         if (MMAP_SIGNAL && !ISR (catching.memory_map))
           {
