@@ -331,9 +331,6 @@ enum markers
   Locker, Log, Name, RCSfile, Revision, Source, State
 };
 
-/* This is used by ‘putdtext’ and ‘scanlogtext’.  */
-#define DELNUMFORM      "\n\n%s\n%s\n"
-
 /* This is used by ci and rlog.  */
 #define EMPTYLOG "*** empty log message ***"
 
@@ -836,6 +833,7 @@ void redefined (int c);
 struct cbuf minus_p (char const *xrev, char const *rev);
 void parse_revpairs (char option, char *arg,
                      void (*put) (char const *b, char const *e, bool sawsep));
+void set_empty_log_message (struct cbuf *cb);
 void ffree (void);
 char *str_save (char const *s);
 char *cgetenv (char const *name);
