@@ -166,7 +166,8 @@ removelock (struct delta *delta)
 static struct wlink newbranch;          /* new branch to be inserted */
 
 static int
-addbranch (struct delta *branchpoint, struct cbuf *num, bool removedlock)
+addbranch (struct delta *branchpoint, struct cbuf *num,
+           bool removedlock, struct wlink **tp_deltas)
 /* Add a new branch and branch delta at ‘branchpoint’.
    If ‘num’ is the null string, append the new branch, incrementing
    the highest branch number (initially 1), and setting the level number to 1.
@@ -236,7 +237,7 @@ addbranch (struct delta *branchpoint, struct cbuf *num, bool removedlock)
       else
         {
           /* Branch exists; append to end.  */
-          targetdelta = delta_from_ref (BRANCHNO (num->string));
+          targetdelta = gr_revno (BRANCHNO (num->string), tp_deltas);
           if (!targetdelta)
             return -1;
           if (!NUM_GT (num->string, targetdelta->num))
@@ -264,6 +265,50 @@ addbranch (struct delta *branchpoint, struct cbuf *num, bool removedlock)
   return removedlock;
 }
 
+static void
+prune (struct delta *wrong, struct delta *bp)
+/* Remove reference to ‘wrong’ from the tree, starting the
+   search at ‘bp’.  As a side effect, clear ‘wrong->selector’.  */
+{
+  struct wlink box, *tp;
+  struct delta *d;
+  int same = countnumflds (wrong->num) - 2;
+
+  /* Unselecting ‘wrong’ is not strictly necessary,
+     but doing so is cleaner.  */
+  wrong->selector = false;
+
+  /* On the trunk, no one points to ‘wrong’, so we are finished.  */
+  if (0 >= same)
+    return;
+
+  /* If ‘wrong’ is the only revision on a branch, delete that branch.  */
+  box.next = bp->branches;
+  for (tp = &box; tp->next; tp = tp->next)
+    if (wrong == (d = tp->next->entry))
+      {
+        tp->next = tp->next->next;
+        bp->branches = box.next;
+        return;
+      }
+
+  /* Otherwise, it must be on normal chain.  */
+  for (tp = bp->branches; tp; tp = tp->next)
+    {
+      d = tp->entry;
+      if (0 == compartial (wrong->num, d->num, same))
+        {
+          while (d->ilk != wrong)
+            d = d->ilk;
+          d->ilk = NULL;
+          return;
+        }
+    }
+
+  /* Should never get here.  */
+  abort ();
+}
+
 static int
 addelta (struct wlink **tp_deltas)
 /* Append a delta to the delta tree, whose number is given by
@@ -334,7 +379,7 @@ addelta (struct wlink **tp_deltas)
             {
               /* Middle revision; start a new branch.  */
               JAM (&newdelnum, "");
-              return addbranch (targetdelta, &newdelnum, true);
+              return addbranch (targetdelta, &newdelnum, true, tp_deltas);
             }
           incnum (targetdelta->num, &newdelnum);
           /* Successful use of existing lock.  */
@@ -402,7 +447,7 @@ addelta (struct wlink **tp_deltas)
           RERR ("can't find branch point %s", old.string);
           return -1;
         }
-      return addbranch (targetdelta, &newdelnum, false);
+      return addbranch (targetdelta, &newdelnum, false, tp_deltas);
     }
 }
 
@@ -542,10 +587,7 @@ getlogmsg (void)
 
   /* Now check whether the log message is not empty.  */
   if (!logmsg.size)
-    {
-      logmsg.string = EMPTYLOG;
-      logmsg.size = sizeof (EMPTYLOG) - 1;
-    }
+    set_empty_log_message (&logmsg);
   return logmsg;
 }
 
@@ -708,7 +750,7 @@ main (int argc, char **argv)
             redefined ('m');
           msg = cleanlogmsg (a, strlen (a));
           if (!msg.size)
-            PERR ("missing message for -m option");
+            set_empty_log_message (&msg);
           break;
 
         case 'n':
@@ -1034,7 +1076,14 @@ main (int argc, char **argv)
                     Orewind (frew);
                     bad_truncate = PROB (ftruncate (fileno (frew), (off_t) 0));
                     grok_resynch (REPO (r));
-                    if (! (workdelta = delta_from_ref (targetdelta->num)))
+
+                    /* The ‘newdelta’ might still be linked in the tree,
+                       so prune it now.  (Unfortunately, ‘grok_resynch’
+                       did not restore the tree completely, as its name
+                       might imply.)  */
+                    prune (&newdelta, targetdelta);
+
+                    if (! (workdelta = gr_revno (targetdelta->num, &deltas)))
                       continue;
                     workdelta->pretty_log = targetdelta->pretty_log;
                     if (newdelta.state != default_state)
