@@ -34,6 +34,7 @@
 #include "b-feph.h"
 #include "b-fro.h"
 #include "b-isr.h"
+#include "b-peer.h"
 
 struct top *top;
 
@@ -53,6 +54,7 @@ struct jstuff
 {
   struct divvy *jstuff;
   struct link head, *tp;
+  struct symdef *merge;
 };
 static struct jstuff jstuff;
 
@@ -108,9 +110,10 @@ rmworkfile (void)
                                     ? ""
                                     : ", and you do not own it")))
         {
-          PERR (!BE (quiet) && ttystdin ()
-                ? "checkout aborted"
-                : "writable %s exists; checkout aborted", mani_filename);
+          if (!BE (quiet) && ttystdin ())
+            PERR ("checkout aborted");
+          else
+            PERR ("writable %s exists; checkout aborted", mani_filename);
           return false;
         }
     }
@@ -203,7 +206,7 @@ getancestor (char const *r1, char const *r2)
   int l1, l2, l3;
   char const *r;
 
-  /* TODO: Don't bother saving in ‘SHARED’.  */
+  /* TODO: Don't bother saving in ‘PLEXUS’.  */
 
   l1 = countnumflds (r1);
   l2 = countnumflds (r2);
@@ -243,6 +246,11 @@ preparejoin (register char *j)
   jstuff.jstuff = make_space ("jstuff");
   jstuff.head.next = NULL;
   jstuff.tp = &jstuff.head;
+  if (! jstuff.merge)
+    {
+      jstuff.merge = ZLLOC (1, struct symdef);
+      jstuff.merge->meaningful = "merge";
+    }
 
   lastjoin = -1;
   for (;;)
@@ -295,7 +303,7 @@ preparejoin (register char *j)
     RFATAL ("empty join");
  done:
 
-  joinlist = pointer_array (SHARED, 1 + lastjoin);
+  joinlist = pointer_array (PLEXUS, 1 + lastjoin);
   jstuff.tp = jstuff.head.next;
   for (int i = 0; i <= lastjoin; i++, jstuff.tp = jstuff.tp->next)
     joinlist[i] = jstuff.tp->entry;
@@ -321,7 +329,7 @@ buildjoin (char const *initialfile)
   rev2 = maketemp (0);
   rev3 = maketemp (3);      /* ‘buildrevision’ may use 1 and 2 */
 
-  cov[1] = prog_co;
+  cov[1] = PEER_CO ();
   /* ‘cov[2]’ setup below.  */
   p = &cov[3];
   if (expandarg)
@@ -336,7 +344,7 @@ buildjoin (char const *initialfile)
   *p++ = REPO (filename);
   *p = '\0';
 
-  mergev[1] = prog_merge;
+  mergev[1] = find_peer_prog (jstuff.merge);
   mergev[2] = mergev[4] = "-L";
   /* Rest of ‘mergev’ setup below.  */
 
@@ -438,8 +446,9 @@ main (int argc, char **argv)
   int stdout_mode = 0;
 #endif
   struct wlink *deltas;                 /* Deltas to be generated.  */
-  struct program program =
+  const struct program program =
     {
+      .invoke = argv[0],
       .name = "co",
       .help = help,
       .exiterr = exiterr
@@ -782,6 +791,7 @@ main (int argc, char **argv)
 
   tempunlink ();
   Ozclose (&MANI (standard_output));
+  gnurcs_goodbye ();
   return exitstatus;
 }
 
