@@ -150,6 +150,7 @@ main (int argc, char **argv)
   char const *a;
   const struct program program =
     {
+      .invoke = argv[0],
       .name = "ident",
       .help = help,
       .exiterr = exiterr
@@ -168,10 +169,12 @@ main (int argc, char **argv)
 
         case 'V':
           display_version (&program);
+          gnurcs_goodbye ();
           return EXIT_SUCCESS;
 
         default:
           bad_option (a - 1);
+          gnurcs_goodbye ();
           return EXIT_FAILURE;
           break;
         }
@@ -197,6 +200,7 @@ main (int argc, char **argv)
       syserror_errno ("standard output");
       status = EXIT_FAILURE;
     }
+  gnurcs_goodbye ();
   return status;
 }
 
