@@ -26,6 +26,17 @@
 
 #define MAKETIMESTUFF(x)  (BE (maketimestuff)-> x)
 
+struct tm *
+local_tm (const time_t *timep, struct tm *result)
+{
+  if (! MAKETIMESTUFF (tzset_called_p))
+    {
+      tzset ();
+      MAKETIMESTUFF (tzset_called_p) = true;
+    }
+  return localtime_r (timep, result);
+}
+
 /* Make no assumptions about the ‘time_t’ epoch or the range of ‘time_t’ values.
    Avoid ‘mktime’ because it's not universal and because there's no easy,
    portable way for ‘mktime’ to return the inverse of ‘gmtime_r’.  */
@@ -38,7 +49,7 @@ isleap (int y)
   return (y & 3) == 0 && (y % 100 != 0 || y % 400 == 0);
 }
 
-static const int const month_yday[] = {
+static int const month_yday[] = {
   /* Days in year before start of months 0-12.  */
   0, 31, 59, 90, 120, 151, 181, 212, 243, 273, 304, 334, 365
 };
@@ -56,7 +67,7 @@ month_days (struct tm const *tm)
 struct tm *
 time2tm (time_t unixtime, bool localzone)
 /* Convert ‘unixtime’ to ‘struct tm’ form.
-   Use ‘gmtime_r’ if available and if ‘!localzone’, ‘localtime_r’ otherwise.  */
+   Use UTC if available and if ‘!localzone’, local time otherwise.  */
 {
   struct tm *tm;
 
@@ -66,7 +77,7 @@ time2tm (time_t unixtime, bool localzone)
       ("The TZ environment variable is not set; please set it to your timezone");
 #endif
   if (localzone || !(tm = gmtime_r (&unixtime, &MAKETIMESTUFF (time2tm_stash))))
-    tm = localtime_r (&unixtime, &MAKETIMESTUFF (time2tm_stash));
+    tm = local_tm (&unixtime, &MAKETIMESTUFF (time2tm_stash));
   return tm;
 }
 
@@ -149,13 +160,12 @@ adjzone (register struct tm *t, long seconds)
 
 time_t
 tm2time (struct tm *tm, bool localzone)
-/* Convert ‘tm’ to ‘time_t’, using ‘localtime_r’ if ‘localzone’ and ‘gmtime_r’
+/* Convert ‘tm’ to ‘time_t’, using local time if ‘localzone’ and UTC
    otherwise.  From ‘tm’, use only ‘year’, ‘mon’, ‘mday’, ‘hour’, ‘min’,
    and ‘sec’ members.  Ignore old members ‘tm_yday’ and ‘tm_wday’, but
    fill in their correct values.  Return -1 on failure (e.g. a member out
    of range).  POSIX 1003.1-1990 doesn't allow leap seconds, but some
-   implementations have them anyway, so allow them if ‘localtime_r’/‘gmtime_r’
-   does.  */
+   implementations have them anyway, so allow them if the host does.  */
 {
   time_t d, gt;
   struct tm const *gtm;
@@ -203,7 +213,7 @@ tm2time (struct tm *tm, bool localzone)
 static time_t
 maketime (struct partime const *pt, time_t default_time)
 /* Check ‘*pt’ and convert it to ‘time_t’.  If it is incompletely specified,
-   use ‘default_time’ to fill it out.  Use ‘localtime_r’ if ‘pt->zone’ is the
+   use ‘default_time’ to fill it out.  Use local time if ‘pt->zone’ is the
    special value ‘TM_LOCAL_ZONE’.  Return -1 on failure.  ISO 8601 day-of-year
    and week numbers are not yet supported.  */
 {
