@@ -20,9 +20,11 @@
 */
 
 #include "base.h"
+#include <stdlib.h>
 #include "merge.help"
 #include "b-complain.h"
 #include "b-feph.h"
+#include "b-merger.h"
 
 struct top *top;
 
@@ -50,11 +52,13 @@ int
 main (int argc, char **argv)
 {
   register char const *a;
-  char const *arg[3], *label[3], *edarg = NULL;
-  int labels;
+  struct symdef three_manifestations[3];
+  char const *edarg = NULL;
+  int labels, exitstatus;
   bool tostdout = false;
   const struct program program =
     {
+      .invoke = argv[0],
       .name = "merge",
       .help = help,
       .exiterr = exiterr
@@ -87,14 +91,15 @@ main (int argc, char **argv)
         case 'L':
           if (3 <= labels)
             PFATAL ("too many -L options");
-          if (!(label[labels++] = *++argv))
+          if (!(LABEL (labels++) = *++argv))
             PFATAL ("-L needs following argument");
           --argc;
           break;
 
         case 'V':
           display_version (&program);
-          return 0;
+          gnurcs_goodbye ();
+          return EXIT_SUCCESS;
 
         default:
           bad_option (a - 2);
@@ -107,17 +112,18 @@ main (int argc, char **argv)
   if (argc != 4)
     PFATAL ("%s arguments", argc < 4 ? "not enough" : "too many");
 
-  /* This copy keeps us ‘const’-clean.  */
-  arg[0] = argv[0];
-  arg[1] = argv[1];
-  arg[2] = argv[2];
-
-  for (; labels < 3; labels++)
-    label[labels] = arg[labels];
+  for (int i = 0; i < 3; i++)
+    {
+      FNAME (i) = argv[i];
+      if (labels <= i)
+        LABEL (i) = FNAME (i);
+    }
 
   if (FLOW (erroneousp))
     exiterr ();
-  return merge (tostdout, edarg, label, arg);
+  exitstatus = merge (tostdout, edarg, three_manifestations);
+  gnurcs_goodbye ();
+  return exitstatus;
 }
 
 /* merge.c ends here */
