@@ -111,7 +111,7 @@ getlocker (char *argv)
   tp = &box;
   while (c != '\0')
     {
-      tp = extend (tp, argv, SHARED);
+      tp = extend (tp, argv, PLEXUS);
       while ((c = *++argv) && c != ',' && c != ' ' && c != '\t' && c != '\n'
              && c != ';')
         continue;
@@ -241,7 +241,7 @@ putrunk (void)
     putadelta (ptr, ptr->ilk, true);
 }
 
-static void putforest (struct wlink const *);
+static void putforest (struct wlink const *branchroot);
 
 static void
 putree (struct delta const *root)
@@ -342,13 +342,13 @@ getauthor (char *argv)
   tp = &box;
   if (c == '\0')
     {
-      tp = extend (tp, getusername (false), SHARED);
+      tp = extend (tp, getusername (false), PLEXUS);
       return;
     }
 
   while (c != '\0')
     {
-      tp = extend (tp, argv, SHARED);
+      tp = extend (tp, argv, PLEXUS);
       while ((c = *++argv) && c != ',' && c != ' ' && c != '\t' && c != '\n'
              && c != ';')
         continue;
@@ -385,7 +385,7 @@ getstate (char *argv)
   tp = &box;
   while (c != '\0')
     {
-      tp = extend (tp, argv, SHARED);
+      tp = extend (tp, argv, PLEXUS);
       while ((c = *++argv) && c != ',' && c != ' ' && c != '\t' && c != '\n'
              && c != ';')
         continue;
@@ -511,7 +511,7 @@ extdate (struct delta *root)
   return revno;
 }
 
-#define PUSH(x,ls)  ls = prepend (x, ls, SHARED)
+#define PUSH(x,ls)  ls = prepend (x, ls, PLEXUS)
 
 static void
 getdatepair (char *argv)
@@ -674,7 +674,7 @@ getnumericrev (void)
           else
             {
               SHACCR (e.string, strrchr (e.string, '.'));
-              accf (SHARED, ".0");
+              accf (PLEXUS, ".0");
               s.string = SHSTR (&s.size);
             }
           break;
@@ -783,6 +783,7 @@ main (int argc, char **argv)
   int revno;
   const struct program program =
     {
+      .invoke = argv[0],
       .name = "rlog",
       .help = help,
       .exiterr = exiterr
@@ -983,7 +984,7 @@ main (int argc, char **argv)
         if (!pre5 || kws != kwsub_kv)
           aprintf (out, "\nkeyword substitution: %s", kwsub_string (kws));
 
-        aprintf (out, "\ntotal revisions: %d", GROK (deltas_count));
+        aprintf (out, "\ntotal revisions: %zu", GROK (deltas_count));
 
         revno = 0;
 
@@ -1025,6 +1026,7 @@ main (int argc, char **argv)
         aputs (equal_line, out);
       }
   Ozclose (&out);
+  gnurcs_goodbye ();
   return exitstatus;
 }
 
